@@ -21,13 +21,13 @@ def render_body(context,**pageargs):
         form = context.get('form', UNDEFINED)
         __M_writer = context.writer()
         if form._use_csrf_protection:
-            __M_writer(u'<input type="hidden" name="csrf_token" value="')
-            __M_writer(unicode(form._csrf_token))
-            __M_writer(u'" />\n')
+            __M_writer('<input type="hidden" name="csrf_token" value="')
+            __M_writer(str(form._csrf_token))
+            __M_writer('" />\n')
         if '_csrf' in form.errors:
-            __M_writer(u'<div class="errors">')
-            __M_writer(unicode(form.errors['_csrf'][0]))
-            __M_writer(u'</div><br />\n')
+            __M_writer('<div class="errors">')
+            __M_writer(str(form.errors['_csrf'][0]))
+            __M_writer('</div><br />\n')
         for field in form:
 
             field_errors = ''
@@ -41,36 +41,36 @@ def render_body(context,**pageargs):
             
             __M_locals_builtin_stored = __M_locals_builtin()
             __M_locals.update(__M_dict_builtin([(__M_key, __M_locals_builtin_stored[__M_key]) for __M_key in ['field_errors','e'] if __M_key in __M_locals_builtin_stored]))
-            __M_writer(u'\n<p>\n')
+            __M_writer('\n<p>\n')
             if 'top' == labels_position:
-                __M_writer(unicode(field.label))
-                __M_writer(u'<br /> ')
+                __M_writer(str(field.label))
+                __M_writer('<br /> ')
             if field_errors and 'top'==errors_position:
-                __M_writer(unicode(field_errors))
-                __M_writer(u'<br /> ')
+                __M_writer(str(field_errors))
+                __M_writer('<br /> ')
             if 'left' == labels_position:
-                __M_writer(unicode(field.label))
-                __M_writer(u' ')
+                __M_writer(str(field.label))
+                __M_writer(' ')
             if field_errors and 'left'==errors_position:
-                __M_writer(unicode(field_errors))
-                __M_writer(u' ')
-            __M_writer(unicode(field))
-            __M_writer(u' ')
+                __M_writer(str(field_errors))
+                __M_writer(' ')
+            __M_writer(str(field))
+            __M_writer(' ')
             if 'bottom' == labels_position:
-                __M_writer(u'<br />')
-                __M_writer(unicode(field.label))
-                __M_writer(u' ')
+                __M_writer('<br />')
+                __M_writer(str(field.label))
+                __M_writer(' ')
             if field_errors and 'bottom'==errors_position:
-                __M_writer(u'<br />')
-                __M_writer(unicode(field_errors))
-                __M_writer(u' ')
+                __M_writer('<br />')
+                __M_writer(str(field_errors))
+                __M_writer(' ')
             if 'right' == labels_position:
-                __M_writer(unicode(field.label))
-                __M_writer(u' ')
+                __M_writer(str(field.label))
+                __M_writer(' ')
             if field_errors and 'right'==errors_position:
-                __M_writer(unicode(field_errors))
-                __M_writer(u' ')
-            __M_writer(u'</p>\n')
+                __M_writer(str(field_errors))
+                __M_writer(' ')
+            __M_writer('</p>\n')
         return ''
     finally:
         context.caller_stack._pop_frame()
